document.addEventListener('DOMContentLoaded', () => {
  const loginBtn = document.getElementById('loginBtn');
  const registerBtn = document.getElementById('registerBtn');
  const loginModal = document.getElementById('loginModal');
  const registerModal = document.getElementById('registerModal');
  const closeBtns = document.querySelectorAll('.close');
  const loginForm = document.getElementById('loginForm');
  const registerForm = document.getElementById('registerForm');
  const albumSection = document.getElementById('albumSection');
  const createAlbumBtn = document.getElementById('createAlbumBtn');
  const albumGrid = document.getElementById('albumGrid');

  let currentUser = null;

  const showModal = (modal) => {
    modal.style.display = 'block';
  };

  const hideModal = (modal) => {
    modal.style.display = 'none';
  };

  loginBtn.addEventListener('click', () => showModal(loginModal));
  registerBtn.addEventListener('click', () => showModal(registerModal));

  closeBtns.forEach(btn => {
    btn.addEventListener('click', () => {
      hideModal(loginModal);
      hideModal(registerModal);
    });
  });

  window.addEventListener('click', (e) => {
    if (e.target === loginModal) hideModal(loginModal);
    if (e.target === registerModal) hideModal(registerModal);
  });

  loginForm.addEventListener('submit', (e) => {
    e.preventDefault();
    // Simulate login
    currentUser = {
      email: loginForm.querySelector('input[type="email"]').value,
      albums: []
    };
    hideModal(loginModal);
    showLoggedInState();
  });

  registerForm.addEventListener('submit', (e) => {
    e.preventDefault();
    // Simulate registration
    currentUser = {
      username: registerForm.querySelector('input[type="text"]').value,
      email: registerForm.querySelector('input[type="email"]').value,
      albums: []
    };
    hideModal(registerModal);
    showLoggedInState();
  });

  createAlbumBtn.addEventListener('click', () => {
    const albumName = prompt('Enter album name:');
    if (albumName) {
      createAlbum(albumName);
    }
  });

  function showLoggedInState() {
    document.querySelector('.hero').classList.add('hidden');
    albumSection.classList.remove('hidden');
    loginBtn.style.display = 'none';
    registerBtn.style.display = 'none';
  }

  function createAlbum(name) {
    const album = document.createElement('div');
    album.className = 'album';
    album.innerHTML = `
      <h3>${name}</h3>
      <input type="file" multiple accept="image/*" style="display: none">
      <button class="upload-btn">Upload Photos</button>
      <div class="photo-grid"></div>
    `;

    const uploadBtn = album.querySelector('.upload-btn');
    const fileInput = album.querySelector('input[type="file"]');
    const photoGrid = album.querySelector('.photo-grid');

    uploadBtn.addEventListener('click', () => {
      fileInput.click();
    });

    fileInput.addEventListener('change', (e) => {
      const files = e.target.files;
      for (let file of files) {
        if (file.type.startsWith('image/')) {
          const reader = new FileReader();
          reader.onload = (e) => {
            const img = document.createElement('img');
            img.src = e.target.result;
            photoGrid.appendChild(img);
          };
          reader.readAsDataURL(file);
        }
      }
    });

    albumGrid.appendChild(album);
  }
});
